@@ -1,6 +1,6 @@
 
 #![doc = include_str!("../docs/python.md")]
-#![doc = include_str!("../docs/python_list.md")]
+#![doc = include_str!("../docs/python_list/showcase.md")]
 
 #![warn(missing_docs)]
 
@@ -14,6 +14,7 @@ pub mod object;
 pub mod list;
 pub mod dict;
 pub mod builtins;
+pub mod boolean;
 
 pub use int::Int;
 pub use float::Float;
@@ -25,4 +26,5 @@ pub use object::_Object;
 pub use dict::Dict;
 pub use builtins::print;
 pub use builtins::len;
-pub use builtins::repr;
\ No newline at end of file
+pub use builtins::repr;
+pub use boolean::Bool;
\ No newline at end of file
